@@ -506,6 +506,9 @@ class Resource(object):
             return self.id == other.id
         return self._info == other._info
 
+    def __ne__(self, other):
+        return not self == other
+
     def is_loaded(self):
         return self._loaded
 
