@@ -12,6 +12,7 @@
 #
 
 import mock
+from oslo_serialization import jsonutils
 
 from congressclient.common import utils
 from congressclient.osc.v1 import datasource
@@ -29,8 +30,8 @@ class TestListDatasources(common.TestCongressBase):
             "results": [{"id": datasource_name,
                          "name": "my_name",
                          "enabled": "True",
-                         "type": "None",
-                         "config": "None"}]
+                         "driver": "driver1",
+                         "config": None}]
         }
         lister = mock.Mock(return_value=response)
         self.app.client_manager.congressclient.list_datasources = lister
@@ -40,8 +41,14 @@ class TestListDatasources(common.TestCongressBase):
         result = cmd.take_action(parsed_args)
 
         lister.assert_called_with()
-        self.assertEqual(['id', 'name', 'enabled', 'type', 'config'],
+        self.assertEqual(['id', 'name', 'enabled', 'driver', 'config'],
                          result[0])
+        for row in result[1]:
+            self.assertEqual(datasource_name, row[0])
+            self.assertEqual("my_name", row[1])
+            self.assertEqual("True", row[2])
+            self.assertEqual("driver1", row[3])
+            self.assertEqual("None", row[4])
 
     def test_list_datasource_output_not_unicode(self):
         # response json string is converted to dict by oslo jsonutils.loads(),
@@ -50,7 +57,7 @@ class TestListDatasources(common.TestCongressBase):
             u"results": [{u"id": u"neutron",
                           u"name": u"my_name",
                           u"enabled": True,
-                          u"type": None,
+                          u"driver": 'driver1',
                           u"config": {
                               u'username': u'admin',
                               u'tenant_name': u'admin',
@@ -67,7 +74,7 @@ class TestListDatasources(common.TestCongressBase):
         result = cmd.take_action(parsed_args)
 
         lister.assert_called_with()
-        self.assertEqual(['id', 'name', 'enabled', 'type', 'config'],
+        self.assertEqual(['id', 'name', 'enabled', 'driver', 'config'],
                          result[0])
         # get 'config' column
         config = list(result[1])[0][-1]
@@ -355,6 +362,31 @@ class TestDeleteDatasourceDriver(common.TestCongressBase):
         self.assertIsNone(result)
 
 
+class TestUpdateDatasourceRow(common.TestCongressBase):
+
+    def test_update_datasource_row(self):
+        driver = 'push'
+        table_name = 'table'
+        rows = [["data1", "data2"],
+                ["data3", "data4"]]
+
+        arglist = [driver, table_name, jsonutils.dumps(rows)]
+        verifylist = [('datasource', driver),
+                      ('table', table_name),
+                      ('rows', rows)]
+
+        mocker = mock.Mock(return_value=None)
+        self.app.client_manager.congressclient.update_datasource_rows = mocker
+        self.app.client_manager.congressclient.list_datasources = mock.Mock()
+
+        cmd = datasource.UpdateDatasourceRow(self.app, self.namespace)
+        parsed_args = self.check_parser(cmd, arglist, verifylist)
+        with mock.patch.object(utils, 'get_resource_id_from_name',
+                               return_value="push"):
+            cmd.take_action(parsed_args)
+        mocker.assert_called_with(driver, table_name, rows)
+
+
 class TestDatasourceRequestRefresh(common.TestCongressBase):
 
     def test_datasource_request_refresh(self):
